@@ -4,7 +4,6 @@
 """
 
 import json
-import time
 
 from .base import HTTPService
 from .._transport.http_transport import HTTPRequestJSON  # type: ignore
@@ -75,7 +74,7 @@ class Request(HTTPRequestJSON):
         elif error in ('ERROR_NO_SLOT_AVAILABLE',):
             # If server returns ERROR_NO_SLOT_AVAILABLE make a 5 seconds timeout before sending
             # next request.
-            time.sleep(5)
+            # time.sleep(5)
             raise exceptions.ServiceTooBusy(error_msg)
         elif error in ('MAX_USER_TURN',) or error.startswith('ERROR:'):
             raise exceptions.TooManyRequestsError(error_msg)
@@ -339,10 +338,14 @@ class RecaptchaV2TaskRequest(TaskRequest):
         # add optional params
         request['data'].update(
             captcha.get_optional_data(
-                data_s=('data-s', None)
+                data_s=('data-s', None),
             )
         )
 
+        # check if enterprise captcha
+        if captcha.is_enterprise:
+            request['data']['enterprise'] = 1
+
         return request
 
 
@@ -363,9 +366,7 @@ class RecaptchaV3TaskRequest(TaskRequest):
                 method="userrecaptcha",
                 version="v3",
                 googlekey=captcha.site_key,
-                pageurl=captcha.page_url,
-                # action=captcha.action,
-                # min_score='{:.1f}'.format(captcha.min_score)
+                pageurl=captcha.page_url
             )
         )
 
@@ -373,10 +374,14 @@ class RecaptchaV3TaskRequest(TaskRequest):
         request['data'].update(
             captcha.get_optional_data(
                 action=('action', None),
-                min_score=('min_score', None)
+                min_score=('min_score', None),
             )
         )
 
+        # check if enterprise captcha
+        if captcha.is_enterprise:
+            request['data']['enterprise'] = 1
+
         return request
 
 
